A collection of Python scripts by me, Alia.
The successor of [anpm](https://pypi.org/project/anpm-public/).

- [PyPi](https://pypi.org/project/alia-apm/)
- [Source Code](https://github.com/AbnormalNormality/apm)
- [Wiki](https://abnormalnormality.github.io/apm/)